@@ -2,13 +2,12 @@ package Kafka::Librd;
 
 use strict;
 use warnings;
+use XSLoader;
+use Exporter::Lite;
 
-our $VERSION = '0.15';
-
-require XSLoader;
+our $VERSION = '0.19';
 XSLoader::load('Kafka::Librd', $VERSION);
 
-use Exporter::Lite;
 our @EXPORT_OK;
 
 =head1 NAME
@@ -92,13 +91,13 @@ subscribe to the list of topics using balanced consumer groups.
 
     $err = $kafka->unsubscribe
 
-unsubscribe from the current subsctiption set
+unsubscribe from the current subscription set
 
 =head2 subscription
 
     $tplist = $kafka->subscription
 
-return current subscription. Subscription returned as a reference to array of
+return current subscriptions. Subscription returned as a reference to array of
 hashes with the following fields: C<topic>, C<partition>, C<offset>, C<metadata>.
 
 =head2 assign
@@ -132,7 +131,7 @@ commit offsets to the broker. C<@tplist> is an array of hashes
 with the following keys: C<topic>, C<partition>, C<offset>, C<metadata>. If
 @topic_partition_list is missing or undef, then current partition assignment
 is used instead. If C<$async> is 1, then method returns immediately, if it is
-0 or missing then method blocks until offsets are commited.
+0 or missing then method blocks until offsets are committed.
 
 =head2 commit_message
 
@@ -145,7 +144,7 @@ L</commit>.
 
     $tplist = $kafka->committed(\@tplist, $timeout_ms)
 
-retrieve commited offsets for topics and partitions specified in C<@tplist>,
+retrieve committed offsets for topics and partitions specified in C<@tplist>,
 which is an array of hashes with C<topic> and C<partition> fields. Returned
 C<$tplist> contains a copy of the input list with added C<offset> fields.
 
@@ -167,8 +166,12 @@ close down the consumer
 
     $topic = $kafka->topic($name, \%config)
 
-return a L</Kafka::Librd::Topic>topic object, that can be used to produce
-messages
+Return a L<topic|/Kafka::Librd::Topic> object, that can be used to produce
+messages.
+
+If an error occurs during creation of the topic, C<undef> is returned. In such
+case use L</Kafka::Librd::Error::last_error> to obtain the corresponding error
+code!
 
 =head2 outq_len
 
@@ -202,13 +205,16 @@ provides the following method:
 
 =head2 produce
 
-    $err = $topic->produce($partition, $msgflags, $payload, $key)
+    $status = $topic->produce($partition, $msgflags, $payload, $key)
 
 produce a message for the topic. I<$msgflags> can be RD_KAFKA_MSG_F_BLOCK in
 the future, but currently it should be set to 0, RD_KAFKA_MSG_F_COPY and
 RD_KAFKA_MSG_F_FREE must not be used, internally RD_KAFKA_MSG_F_COPY is always
 set.
 
+The returned status is -1 in case of an error, otherwise 0. The error code can
+be retrieved using the L</Kafka::Librd::Error::last_error> function.
+
 =head2 destroy
 
     $topic->destroy
@@ -254,14 +260,38 @@ scalar reference. It will be filled with one of the following values:
 
 =over
 
-=item Kafka::Librd::RD_KAFKA_TIMESTAMP_NOT_AVAILABLE
+=item
 
-=item Kafka::Librd::RD_KAFKA_TIMESTAMP_CREATE_TIME
+C<Kafka::Librd::RD_KAFKA_TIMESTAMP_NOT_AVAILABLE>
 
-=item Kafka::Librd::RD_KAFKA_TIMESTAMP_LOG_APPEND_TIME
+=item
+
+C<Kafka::Librd::RD_KAFKA_TIMESTAMP_CREATE_TIME>
+
+=item
+
+C<Kafka::Librd::RD_KAFKA_TIMESTAMP_LOG_APPEND_TIME>
 
 =back
 
+=head1 Kafka::Librd::Error
+
+=head2 Kafka::Librd::Error::to_string
+
+   my $error_message =  Kafka::Librd::Error::to_string($err)
+
+Convert an error code into a human-readable error description. Use this for
+error codes returned by L</Kafka::Librd::Error::last_error> and
+L<Kafka::Librd::Message::err|/err>.
+
+=head2 Kafka::Librd::Error::last_error
+
+    my $err = Kafka::Librd::Error::last_error
+
+Retrieve the last error state set by function calls L</topic> and L</produce>.
+This function should be called immediately after those functions, since they
+store error information globally.
+
 =cut
 
 package Kafka::Librd;
@@ -275,7 +305,8 @@ __END__
 
 =head1 CAVEATS
 
-Message offset is truncated to 32 bit if perl compiled without support for 64 bit integers.
+Message offset is truncated to 32 bit if perl compiled without support for
+64 bit integers.
 
 =head1 SEE ALSO
 
